==> calamares-settings-solydxk_4.12%2Br13.tar.xz: source/ts/calamares-solydxk_lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Dėkojame, kad pasirinkote SolydXK&lt;/h3&gt;&lt;br /&gt;Jūs pasirinkote Linux distribuciją, kuri yra:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Saugi ir stabili&lt;/li&gt;&lt;li&gt;Greita ir reaguojanti&lt;/li&gt;&lt;li&gt;Su paruoštu naudoti darbalaukiu&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Mėgaukitės šia nauja laida ir ačiū, kad pasirinkote SolydXK.&lt;br /&gt;&lt;br /&gt;Įdiegimas, priklausomai nuo jūsų nustatymų, užtrunka 15-30 minučių.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Atsistoję ant milžino pečių&lt;/h3&gt;&lt;br /&gt;SolydXK yra Debian pagrįsta GNU/Linux distribucija, kuri yra kilusi iš Debian ir yra su ja suderinama.&lt;br /&gt;&lt;br /&gt;SolydXK naudoja arba supaprastintą Xfce darbalaukį, skirtą SolydX, arba plačiai konfigūruojamą, stulbinančiai patrauklų KDE darbalaukį, skirtą SolydK.&lt;br /&gt;&lt;br /&gt;Mūsų inovacijos, spartus Debian kūrimas ir milžiniškas Debian paketų pasirinkimas padaro SolydXK viena iš labiausiai patrauklių, namų naudotojams prieinamų, darbalaukio operacinių sistemų.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Viskas vienoje vietoje&lt;/h3&gt;&lt;br /&gt;Sistemoje SolydXK, programos Firefox, Thunderbird ir LibreOffice yra iš anksto įdiegtos, taigi, nedelsdami galite pradėti darbą darbalaukyje ir internete.&lt;br /&gt;&lt;br /&gt;Kitaip nei kitos Linux distribucijos, SolydXK taip pat yra paruošta groti jūsų muziką, internetinius vaizdo įrašus ir daugiau.&lt;br /&gt;&lt;br /&gt;Didelė įvairovė programinės įrangos gali būti įdiegta vienu pelės spustelėjimu.&lt;br /&gt;&lt;br /&gt;SolydXK yra suderinama su daugeliu populiarių failų formatų, tokių kaip: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, ir daug daugiau.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Raštinės įrankiai yra paruošti, iš karto jums įdiegus SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice , galingas raštinės programų rinkinys, pateikiamas jau įtaisytas į SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice  yra lengvai naudojamas ir perprantamas.&lt;br /&gt;&lt;br /&gt;Šį programų rinkinį galite naudoti, norėdami kurti tekstus, pateiktis ir skaičiuokles, o taip pat diagramas bei duomenų bazes.&lt;br /&gt;&lt;br /&gt;LibreOffice  naudoja standartinį OpenDocument formatą ir veikia su kitais, populiarių raštinės programų, įskaitant WordPerfect ir Microsoft Office, dokumentais.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.&lt;br /&gt;&lt;br /&gt;SolydXK can detect other operating systems and install itself beside them.You can choose which operating system to launch when you start the computer.</source>
        <translation>&lt;h3&gt;Alternatyva vyraujančioms operacinėms sistemoms&lt;/h3&gt;&lt;br /&gt;SolydXK yra lengva naudoti, galinga ir konfigūruojama.&lt;br /&gt;&lt;br /&gt;SolydXK yra saugi ir stabili. Kitaip nei kitos operacinės sistemos, ji nėra linkusi užsikrėsti kompiuteriniais virusais ar šnipinėjimo programomis, ji nepatiria disko fragmentacijos ir joje nėra registro, kuris reikalautų periodinio valymo.&lt;br /&gt;&lt;br /&gt;SolydXK gali aptikti kitas operacines sistemas ir įsidiegti šalia jų. Įjungę kompiuterį, galite pasirinkti, kurią operacinę sistemą norėtumėte naudoti.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="143"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Saugūs atnaujinimai&lt;/h3&gt;&lt;br /&gt;Kai kurios operacinės sistemos padaro jūsų sistemos atnaujinimą sunkesnį, nei jis turėtų būti. SolydXK mano, kad naujinimai turėtų būti greiti ir lengvi, ir nesimaišyti po kojom.&lt;br /&gt;&lt;br /&gt;Atnaujinimų tvarkytuvė nepastebimai budi sistemos dėkle ir praneša jums, kai yra prieinami atnaujinimai. Jūs neprivalote taikyti atnaujinimų, kai to daryti nenorite. Atnaujinimų tvarkytuvė nepasirodys ir jokiu kitu būdu jūsų neerzins.&lt;br /&gt;&lt;br /&gt;Visi atnaujinti failai yra prižiūrimi ir atidžiai tikrinami mūsų patikimų kūrėjų ir prižiūrėtojų.&lt;br /&gt;&lt;br /&gt;Visi failai, jūsų naudojimui yra talpinami saugiose saugyklose.&lt;br /&gt;&lt;br /&gt;Saugumo saugykla yra kasdieną sinchronizuojama.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="165"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Nuostabi bendruomenė&lt;/h3&gt;&lt;br /&gt;SolydXK naudotojai džiaugiasi galėdami pasidalyti savo aistra ir entuziazmu, o taip pat gebėjimu padėti. Nesivaržykite užduoti klausimus forumuose ar įsitraukti į bendruomenę.&lt;br /&gt;&lt;br /&gt;Siųskite mums savo atsiliepimus ir papasakokite apie savo įspūdžius. Mes išklausysime jūsų idėjas ir panaudosime jas tolimesniam SolydXK tobulinimui.</translation>
    </message>
</context>
</TS>

==> calamares-settings-solydxk_4.27%2Br13.tar.xz: source/ts/calamares-solydxk_lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Dėkojame, kad pasirinkote SolydXK&lt;/h3&gt;&lt;br /&gt;Jūs pasirinkote Linux distribuciją, kuri yra:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Saugi ir stabili&lt;/li&gt;&lt;li&gt;Greita ir reaguojanti&lt;/li&gt;&lt;li&gt;Su paruoštu naudoti darbalaukiu&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Mėgaukitės šia nauja laida ir ačiū, kad pasirinkote SolydXK.&lt;br /&gt;&lt;br /&gt;Įdiegimas, priklausomai nuo jūsų nustatymų, užtrunka 15-30 minučių.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Atsistoję ant milžino pečių&lt;/h3&gt;&lt;br /&gt;SolydXK yra Debian pagrįsta GNU/Linux distribucija, kuri yra kilusi iš Debian ir yra su ja suderinama.&lt;br /&gt;&lt;br /&gt;SolydXK naudoja arba supaprastintą Xfce darbalaukį, skirtą SolydX, arba plačiai konfigūruojamą, stulbinančiai patrauklų KDE darbalaukį, skirtą SolydK.&lt;br /&gt;&lt;br /&gt;Mūsų inovacijos, spartus Debian kūrimas ir milžiniškas Debian paketų pasirinkimas padaro SolydXK viena iš labiausiai patrauklių, namų naudotojams prieinamų, darbalaukio operacinių sistemų.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Viskas vienoje vietoje&lt;/h3&gt;&lt;br /&gt;Sistemoje SolydXK, programos Firefox, Thunderbird ir LibreOffice yra iš anksto įdiegtos, taigi, nedelsdami galite pradėti darbą darbalaukyje ir internete.&lt;br /&gt;&lt;br /&gt;Kitaip nei kitos Linux distribucijos, SolydXK taip pat yra paruošta groti jūsų muziką, internetinius vaizdo įrašus ir daugiau.&lt;br /&gt;&lt;br /&gt;Didelė įvairovė programinės įrangos gali būti įdiegta vienu pelės spustelėjimu.&lt;br /&gt;&lt;br /&gt;SolydXK yra suderinama su daugeliu populiarių failų formatų, tokių kaip: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, ir daug daugiau.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Raštinės įrankiai yra paruošti, iš karto jums įdiegus SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice , galingas raštinės programų rinkinys, pateikiamas jau įtaisytas į SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice  yra lengvai naudojamas ir perprantamas.&lt;br /&gt;&lt;br /&gt;Šį programų rinkinį galite naudoti, norėdami kurti tekstus, pateiktis ir skaičiuokles, o taip pat diagramas bei duomenų bazes.&lt;br /&gt;&lt;br /&gt;LibreOffice  naudoja standartinį OpenDocument formatą ir veikia su kitais, populiarių raštinės programų, įskaitant WordPerfect ir Microsoft Office, dokumentais.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.</source>
        <translation>&lt;h3&gt;Alternatyva vyraujančioms operacinėms sistemoms&lt;/h3&gt;&lt;br /&gt;SolydXK yra lengva naudoti, galinga ir konfigūruojama.&lt;br /&gt;&lt;br /&gt;SolydXK yra saugi ir stabili. Kitaip nei kitos operacinės sistemos, ji nėra linkusi užsikrėsti kompiuteriniais virusais ar šnipinėjimo programomis, ji nepatiria disko fragmentacijos ir joje nėra registro, kuris reikalautų periodinio valymo.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="142"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Saugūs atnaujinimai&lt;/h3&gt;&lt;br /&gt;Kai kurios operacinės sistemos padaro jūsų sistemos atnaujinimą sunkesnį, nei jis turėtų būti. SolydXK mano, kad naujinimai turėtų būti greiti ir lengvi, ir nesimaišyti po kojom.&lt;br /&gt;&lt;br /&gt;Atnaujinimų tvarkytuvė nepastebimai budi sistemos dėkle ir praneša jums, kai yra prieinami atnaujinimai. Jūs neprivalote taikyti atnaujinimų, kai to daryti nenorite. Atnaujinimų tvarkytuvė nepasirodys ir jokiu kitu būdu jūsų neerzins.&lt;br /&gt;&lt;br /&gt;Visi atnaujinti failai yra prižiūrimi ir atidžiai tikrinami mūsų patikimų kūrėjų ir prižiūrėtojų.&lt;br /&gt;&lt;br /&gt;Visi failai, jūsų naudojimui yra talpinami saugiose saugyklose.&lt;br /&gt;&lt;br /&gt;Saugumo saugykla yra kasdieną sinchronizuojama.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="164"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Nuostabi bendruomenė&lt;/h3&gt;&lt;br /&gt;SolydXK naudotojai džiaugiasi galėdami pasidalyti savo aistra ir entuziazmu, o taip pat gebėjimu padėti. Nesivaržykite užduoti klausimus forumuose ar įsitraukti į bendruomenę.&lt;br /&gt;&lt;br /&gt;Siųskite mums savo atsiliepimus ir papasakokite apie savo įspūdžius. Mes išklausysime jūsų idėjas ir panaudosime jas tolimesniam SolydXK tobulinimui.</translation>
    </message>
</context>
</TS>
